# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from ._models_py3 import Activity
from ._models_py3 import ActivityDependency
from ._models_py3 import ActivityPolicy
from ._models_py3 import ActivityRun
from ._models_py3 import ActivityRunsQueryResponse
from ._models_py3 import AddDataFlowToDebugSessionResponse
from ._models_py3 import AdditionalColumns
from ._models_py3 import AmazonMWSLinkedService
from ._models_py3 import AmazonMWSObjectDataset
from ._models_py3 import AmazonMWSSource
from ._models_py3 import AmazonRdsForOracleLinkedService
from ._models_py3 import AmazonRdsForOraclePartitionSettings
from ._models_py3 import AmazonRdsForOracleSource
from ._models_py3 import AmazonRdsForOracleTableDataset
from ._models_py3 import AmazonRdsForSqlServerLinkedService
from ._models_py3 import AmazonRdsForSqlServerLinkedServiceTypeProperties
from ._models_py3 import AmazonRdsForSqlServerSource
from ._models_py3 import AmazonRdsForSqlServerTableDataset
from ._models_py3 import AmazonRedshiftLinkedService
from ._models_py3 import AmazonRedshiftSource
from ._models_py3 import AmazonRedshiftTableDataset
from ._models_py3 import AmazonS3Dataset
from ._models_py3 import AmazonS3LinkedService
from ._models_py3 import AmazonS3Location
from ._models_py3 import AmazonS3ReadSettings
from ._models_py3 import AppFiguresLinkedService
from ._models_py3 import AppendVariableActivity
from ._models_py3 import ArtifactRenameRequest
from ._models_py3 import AsanaLinkedService
from ._models_py3 import AutoPauseProperties
from ._models_py3 import AutoScaleProperties
from ._models_py3 import AvroDataset
from ._models_py3 import AvroFormat
from ._models_py3 import AvroSink
from ._models_py3 import AvroSource
from ._models_py3 import AvroWriteSettings
from ._models_py3 import AzureBatchLinkedService
from ._models_py3 import AzureBlobDataset
from ._models_py3 import AzureBlobFSDataset
from ._models_py3 import AzureBlobFSLinkedService
from ._models_py3 import AzureBlobFSLocation
from ._models_py3 import AzureBlobFSReadSettings
from ._models_py3 import AzureBlobFSSink
from ._models_py3 import AzureBlobFSSource
from ._models_py3 import AzureBlobFSWriteSettings
from ._models_py3 import AzureBlobStorageLinkedService
from ._models_py3 import AzureBlobStorageLocation
from ._models_py3 import AzureBlobStorageReadSettings
from ._models_py3 import AzureBlobStorageWriteSettings
from ._models_py3 import AzureDataExplorerCommandActivity
from ._models_py3 import AzureDataExplorerLinkedService
from ._models_py3 import AzureDataExplorerSink
from ._models_py3 import AzureDataExplorerSource
from ._models_py3 import AzureDataExplorerTableDataset
from ._models_py3 import AzureDataLakeAnalyticsLinkedService
from ._models_py3 import AzureDataLakeStoreDataset
from ._models_py3 import AzureDataLakeStoreLinkedService
from ._models_py3 import AzureDataLakeStoreLocation
from ._models_py3 import AzureDataLakeStoreReadSettings
from ._models_py3 import AzureDataLakeStoreSink
from ._models_py3 import AzureDataLakeStoreSource
from ._models_py3 import AzureDataLakeStoreWriteSettings
from ._models_py3 import AzureDatabricksDeltaLakeDataset
from ._models_py3 import AzureDatabricksDeltaLakeExportCommand
from ._models_py3 import AzureDatabricksDeltaLakeImportCommand
from ._models_py3 import AzureDatabricksDeltaLakeLinkedService
from ._models_py3 import AzureDatabricksDeltaLakeSink
from ._models_py3 import AzureDatabricksDeltaLakeSource
from ._models_py3 import AzureDatabricksLinkedService
from ._models_py3 import AzureEntityResource
from ._models_py3 import AzureFileStorageLinkedService
from ._models_py3 import AzureFileStorageLocation
from ._models_py3 import AzureFileStorageReadSettings
from ._models_py3 import AzureFileStorageWriteSettings
from ._models_py3 import AzureFunctionActivity
from ._models_py3 import AzureFunctionLinkedService
from ._models_py3 import AzureKeyVaultLinkedService
from ._models_py3 import AzureKeyVaultSecretReference
from ._models_py3 import AzureMLBatchExecutionActivity
from ._models_py3 import AzureMLExecutePipelineActivity
from ._models_py3 import AzureMLLinkedService
from ._models_py3 import AzureMLServiceLinkedService
from ._models_py3 import AzureMLUpdateResourceActivity
from ._models_py3 import AzureMLWebServiceFile
from ._models_py3 import AzureMariaDBLinkedService
from ._models_py3 import AzureMariaDBSource
from ._models_py3 import AzureMariaDBTableDataset
from ._models_py3 import AzureMySqlLinkedService
from ._models_py3 import AzureMySqlSink
from ._models_py3 import AzureMySqlSource
from ._models_py3 import AzureMySqlTableDataset
from ._models_py3 import AzurePostgreSqlLinkedService
from ._models_py3 import AzurePostgreSqlSink
from ._models_py3 import AzurePostgreSqlSinkUpsertSettings
from ._models_py3 import AzurePostgreSqlSource
from ._models_py3 import AzurePostgreSqlTableDataset
from ._models_py3 import AzureQueueSink
from ._models_py3 import AzureSearchIndexDataset
from ._models_py3 import AzureSearchIndexSink
from ._models_py3 import AzureSearchLinkedService
from ._models_py3 import AzureSqlDWLinkedService
from ._models_py3 import AzureSqlDWLinkedServiceTypeProperties
from ._models_py3 import AzureSqlDWTableDataset
from ._models_py3 import AzureSqlDatabaseLinkedService
from ._models_py3 import AzureSqlDatabaseLinkedServiceTypeProperties
from ._models_py3 import AzureSqlMILinkedService
from ._models_py3 import AzureSqlMILinkedServiceTypeProperties
from ._models_py3 import AzureSqlMITableDataset
from ._models_py3 import AzureSqlSink
from ._models_py3 import AzureSqlSource
from ._models_py3 import AzureSqlTableDataset
from ._models_py3 import AzureStorageLinkedService
from ._models_py3 import AzureStorageLinkedServiceTypeProperties
from ._models_py3 import AzureSynapseArtifactsLinkedService
from ._models_py3 import AzureTableDataset
from ._models_py3 import AzureTableSink
from ._models_py3 import AzureTableSource
from ._models_py3 import AzureTableStorageLinkedService
from ._models_py3 import AzureTableStorageLinkedServiceTypeProperties
from ._models_py3 import BigDataPoolParametrizationReference
from ._models_py3 import BigDataPoolReference
from ._models_py3 import BigDataPoolResourceInfo
from ._models_py3 import BigDataPoolResourceInfoListResult
from ._models_py3 import BinaryDataset
from ._models_py3 import BinaryReadSettings
from ._models_py3 import BinarySink
from ._models_py3 import BinarySource
from ._models_py3 import BlobEventsTrigger
from ._models_py3 import BlobSink
from ._models_py3 import BlobSource
from ._models_py3 import BlobTrigger
from ._models_py3 import CassandraLinkedService
from ._models_py3 import CassandraSource
from ._models_py3 import CassandraTableDataset
from ._models_py3 import ChainingTrigger
from ._models_py3 import CloudError
from ._models_py3 import CommonDataServiceForAppsEntityDataset
from ._models_py3 import CommonDataServiceForAppsLinkedService
from ._models_py3 import CommonDataServiceForAppsSink
from ._models_py3 import CommonDataServiceForAppsSource
from ._models_py3 import CompressionReadSettings
from ._models_py3 import ConcurLinkedService
from ._models_py3 import ConcurObjectDataset
from ._models_py3 import ConcurSource
from ._models_py3 import ContinuationSettingsReference
from ._models_py3 import ControlActivity
from ._models_py3 import CopyActivity
from ._models_py3 import CopyActivityLogSettings
from ._models_py3 import CopySink
from ._models_py3 import CopySource
from ._models_py3 import CopyTranslator
from ._models_py3 import CosmosDbLinkedService
from ._models_py3 import CosmosDbMongoDbApiCollectionDataset
from ._models_py3 import CosmosDbMongoDbApiLinkedService
from ._models_py3 import CosmosDbMongoDbApiSink
from ._models_py3 import CosmosDbMongoDbApiSource
from ._models_py3 import CosmosDbSqlApiCollectionDataset
from ._models_py3 import CosmosDbSqlApiSink
from ._models_py3 import CosmosDbSqlApiSource
from ._models_py3 import CouchbaseLinkedService
from ._models_py3 import CouchbaseSource
from ._models_py3 import CouchbaseTableDataset
from ._models_py3 import CreateDataFlowDebugSessionRequest
from ._models_py3 import CreateDataFlowDebugSessionResponse
from ._models_py3 import CreateRunResponse
from ._models_py3 import CredentialReference
from ._models_py3 import CustomActivity
from ._models_py3 import CustomActivityReferenceObject
from ._models_py3 import CustomDataSourceLinkedService
from ._models_py3 import CustomDataset
from ._models_py3 import CustomEventsTrigger
from ._models_py3 import CustomSetupBase
from ._models_py3 import CustomerManagedKeyDetails
from ._models_py3 import DWCopyCommandDefaultValue
from ._models_py3 import DWCopyCommandSettings
from ._models_py3 import DataFlow
from ._models_py3 import DataFlowDebugCommandPayload
from ._models_py3 import DataFlowDebugCommandRequest
from ._models_py3 import DataFlowDebugCommandResponse
from ._models_py3 import DataFlowDebugPackage
from ._models_py3 import DataFlowDebugPackageDebugSettings
from ._models_py3 import DataFlowDebugPreviewDataRequest
from ._models_py3 import DataFlowDebugQueryResponse
from ._models_py3 import DataFlowDebugResource
from ._models_py3 import DataFlowDebugResultResponse
from ._models_py3 import DataFlowDebugSessionInfo
from ._models_py3 import DataFlowDebugStatisticsRequest
from ._models_py3 import DataFlowFolder
from ._models_py3 import DataFlowListResponse
from ._models_py3 import DataFlowReference
from ._models_py3 import DataFlowResource
from ._models_py3 import DataFlowSink
from ._models_py3 import DataFlowSource
from ._models_py3 import DataFlowSourceSetting
from ._models_py3 import DataFlowStagingInfo
from ._models_py3 import DataLakeAnalyticsUSQLActivity
from ._models_py3 import DataLakeStorageAccountDetails
from ._models_py3 import DatabricksNotebookActivity
from ._models_py3 import DatabricksSparkJarActivity
from ._models_py3 import DatabricksSparkPythonActivity
from ._models_py3 import Dataset
from ._models_py3 import DatasetCompression
from ._models_py3 import DatasetDataElement
from ._models_py3 import DatasetDebugResource
from ._models_py3 import DatasetFolder
from ._models_py3 import DatasetListResponse
from ._models_py3 import DatasetLocation
from ._models_py3 import DatasetReference
from ._models_py3 import DatasetResource
from ._models_py3 import DatasetSchemaDataElement
from ._models_py3 import DatasetStorageFormat
from ._models_py3 import DataworldLinkedService
from ._models_py3 import Db2LinkedService
from ._models_py3 import Db2Source
from ._models_py3 import Db2TableDataset
from ._models_py3 import DeleteActivity
from ._models_py3 import DeleteDataFlowDebugSessionRequest
from ._models_py3 import DelimitedTextDataset
from ._models_py3 import DelimitedTextReadSettings
from ._models_py3 import DelimitedTextSink
from ._models_py3 import DelimitedTextSource
from ._models_py3 import DelimitedTextWriteSettings
from ._models_py3 import DependencyReference
from ._models_py3 import DistcpSettings
from ._models_py3 import DocumentDbCollectionDataset
from ._models_py3 import DocumentDbCollectionSink
from ._models_py3 import DocumentDbCollectionSource
from ._models_py3 import DrillLinkedService
from ._models_py3 import DrillSource
from ._models_py3 import DrillTableDataset
from ._models_py3 import DynamicExecutorAllocation
from ._models_py3 import DynamicsAXLinkedService
from ._models_py3 import DynamicsAXResourceDataset
from ._models_py3 import DynamicsAXSource
from ._models_py3 import DynamicsCrmEntityDataset
from ._models_py3 import DynamicsCrmLinkedService
from ._models_py3 import DynamicsCrmSink
from ._models_py3 import DynamicsCrmSource
from ._models_py3 import DynamicsEntityDataset
from ._models_py3 import DynamicsLinkedService
from ._models_py3 import DynamicsSink
from ._models_py3 import DynamicsSource
from ._models_py3 import EditTablesRequest
from ._models_py3 import EloquaLinkedService
from ._models_py3 import EloquaObjectDataset
from ._models_py3 import EloquaSource
from ._models_py3 import EncryptionDetails
from ._models_py3 import EntityReference
from ._models_py3 import ErrorAdditionalInfo
from ._models_py3 import ErrorContract
from ._models_py3 import ErrorResponse
from ._models_py3 import EvaluateDataFlowExpressionRequest
from ._models_py3 import ExcelDataset
from ._models_py3 import ExcelSource
from ._models_py3 import ExecuteDataFlowActivity
from ._models_py3 import ExecuteDataFlowActivityTypePropertiesCompute
from ._models_py3 import ExecutePipelineActivity
from ._models_py3 import ExecuteSSISPackageActivity
from ._models_py3 import ExecutionActivity
from ._models_py3 import ExportSettings
from ._models_py3 import ExposureControlRequest
from ._models_py3 import ExposureControlResponse
from ._models_py3 import Expression
from ._models_py3 import ExpressionV2
from ._models_py3 import FailActivity
from ._models_py3 import FileServerLinkedService
from ._models_py3 import FileServerLocation
from ._models_py3 import FileServerReadSettings
from ._models_py3 import FileServerWriteSettings
from ._models_py3 import FileShareDataset
from ._models_py3 import FileSystemSink
from ._models_py3 import FileSystemSource
from ._models_py3 import FilterActivity
from ._models_py3 import Flowlet
from ._models_py3 import ForEachActivity
from ._models_py3 import FormatReadSettings
from ._models_py3 import FormatWriteSettings
from ._models_py3 import FtpReadSettings
from ._models_py3 import FtpServerLinkedService
from ._models_py3 import FtpServerLocation
from ._models_py3 import GetMetadataActivity
from ._models_py3 import GetSsisObjectMetadataRequest
from ._models_py3 import GitHubAccessTokenRequest
from ._models_py3 import GitHubAccessTokenResponse
from ._models_py3 import GitHubClientSecret
from ._models_py3 import GoogleAdWordsLinkedService
from ._models_py3 import GoogleAdWordsObjectDataset
from ._models_py3 import GoogleAdWordsSource
from ._models_py3 import GoogleBigQueryLinkedService
from ._models_py3 import GoogleBigQueryObjectDataset
from ._models_py3 import GoogleBigQuerySource
from ._models_py3 import GoogleBigQueryV2LinkedService
from ._models_py3 import GoogleBigQueryV2ObjectDataset
from ._models_py3 import GoogleBigQueryV2Source
from ._models_py3 import GoogleCloudStorageLinkedService
from ._models_py3 import GoogleCloudStorageLocation
from ._models_py3 import GoogleCloudStorageReadSettings
from ._models_py3 import GoogleSheetsLinkedService
from ._models_py3 import GreenplumLinkedService
from ._models_py3 import GreenplumSource
from ._models_py3 import GreenplumTableDataset
from ._models_py3 import HBaseLinkedService
from ._models_py3 import HBaseObjectDataset
from ._models_py3 import HBaseSource
from ._models_py3 import HDInsightHiveActivity
from ._models_py3 import HDInsightLinkedService
from ._models_py3 import HDInsightMapReduceActivity
from ._models_py3 import HDInsightOnDemandLinkedService
from ._models_py3 import HDInsightPigActivity
from ._models_py3 import HDInsightSparkActivity
from ._models_py3 import HDInsightStreamingActivity
from ._models_py3 import HdfsLinkedService
from ._models_py3 import HdfsLocation
from ._models_py3 import HdfsReadSettings
from ._models_py3 import HdfsSource
from ._models_py3 import HiveLinkedService
from ._models_py3 import HiveObjectDataset
from ._models_py3 import HiveSource
from ._models_py3 import HttpDataset
from ._models_py3 import HttpLinkedService
from ._models_py3 import HttpReadSettings
from ._models_py3 import HttpServerLocation
from ._models_py3 import HttpSource
from ._models_py3 import HubspotLinkedService
from ._models_py3 import HubspotObjectDataset
from ._models_py3 import HubspotSource
from ._models_py3 import IcebergDataset
from ._models_py3 import IcebergSink
from ._models_py3 import IcebergWriteSettings
from ._models_py3 import IfConditionActivity
from ._models_py3 import ImpalaLinkedService
from ._models_py3 import ImpalaObjectDataset
from ._models_py3 import ImpalaSource
from ._models_py3 import ImportSettings
from ._models_py3 import InformixLinkedService
from ._models_py3 import InformixSink
from ._models_py3 import InformixSource
from ._models_py3 import InformixTableDataset
from ._models_py3 import IntegrationRuntime
from ._models_py3 import IntegrationRuntimeComputeProperties
from ._models_py3 import IntegrationRuntimeCustomSetupScriptProperties
from ._models_py3 import IntegrationRuntimeDataFlowProperties
from ._models_py3 import IntegrationRuntimeDataProxyProperties
from ._models_py3 import IntegrationRuntimeDebugResource
from ._models_py3 import IntegrationRuntimeListResponse
from ._models_py3 import IntegrationRuntimeReference
from ._models_py3 import IntegrationRuntimeResource
from ._models_py3 import IntegrationRuntimeSsisCatalogInfo
from ._models_py3 import IntegrationRuntimeSsisProperties
from ._models_py3 import IntegrationRuntimeVNetProperties
from ._models_py3 import JiraLinkedService
from ._models_py3 import JiraObjectDataset
from ._models_py3 import JiraSource
from ._models_py3 import JsonDataset
from ._models_py3 import JsonFormat
from ._models_py3 import JsonReadSettings
from ._models_py3 import JsonSink
from ._models_py3 import JsonSource
from ._models_py3 import JsonWriteSettings
from ._models_py3 import KqlScript
from ._models_py3 import KqlScriptContent
from ._models_py3 import KqlScriptContentCurrentConnection
from ._models_py3 import KqlScriptContentMetadata
from ._models_py3 import KqlScriptResource
from ._models_py3 import KqlScriptsResourceCollectionResponse
from ._models_py3 import LakeHouseLinkedService
from ._models_py3 import LakeHouseLocation
from ._models_py3 import LakeHouseReadSettings
from ._models_py3 import LakeHouseTableDataset
from ._models_py3 import LakeHouseTableSink
from ._models_py3 import LakeHouseTableSource
from ._models_py3 import LakeHouseWriteSettings
from ._models_py3 import LibraryInfo
from ._models_py3 import LibraryListResponse
from ._models_py3 import LibraryRequirements
from ._models_py3 import LibraryResource
from ._models_py3 import LibraryResourceInfo
from ._models_py3 import LibraryResourceProperties
from ._models_py3 import LinkConnection
from ._models_py3 import LinkConnectionCompute
from ._models_py3 import LinkConnectionDetailedStatus
from ._models_py3 import LinkConnectionLandingZone
from ._models_py3 import LinkConnectionListResponse
from ._models_py3 import LinkConnectionQueryTableStatus
from ._models_py3 import LinkConnectionRefreshStatus
from ._models_py3 import LinkConnectionResource
from ._models_py3 import LinkConnectionSourceDatabase
from ._models_py3 import LinkConnectionSourceDatabaseTypeProperties
from ._models_py3 import LinkConnectionTargetDatabase
from ._models_py3 import LinkConnectionTargetDatabaseTypeProperties
from ._models_py3 import LinkTableListResponse
from ._models_py3 import LinkTableRequest
from ._models_py3 import LinkTableRequestSource
from ._models_py3 import LinkTableRequestTarget
from ._models_py3 import LinkTableRequestTargetDistributionOptions
from ._models_py3 import LinkTableRequestTargetStructureOptions
from ._models_py3 import LinkTableResource
from ._models_py3 import LinkTableStatus
from ._models_py3 import LinkedIntegrationRuntimeKeyAuthorization
from ._models_py3 import LinkedIntegrationRuntimeRbacAuthorization
from ._models_py3 import LinkedIntegrationRuntimeType
from ._models_py3 import LinkedService
from ._models_py3 import LinkedServiceDebugResource
from ._models_py3 import LinkedServiceListResponse
from ._models_py3 import LinkedServiceReference
from ._models_py3 import LinkedServiceResource
from ._models_py3 import LogLocationSettings
from ._models_py3 import LogSettings
from ._models_py3 import LogStorageSettings
from ._models_py3 import LookupActivity
from ._models_py3 import MagentoLinkedService
from ._models_py3 import MagentoObjectDataset
from ._models_py3 import MagentoSource
from ._models_py3 import ManagedIdentity
from ._models_py3 import ManagedIntegrationRuntime
from ._models_py3 import ManagedVirtualNetworkReference
from ._models_py3 import ManagedVirtualNetworkSettings
from ._models_py3 import MappingDataFlow
from ._models_py3 import MariaDBLinkedService
from ._models_py3 import MariaDBSource
from ._models_py3 import MariaDBTableDataset
from ._models_py3 import MarketoLinkedService
from ._models_py3 import MarketoObjectDataset
from ._models_py3 import MarketoSource
from ._models_py3 import MetadataItem
from ._models_py3 import MetastoreRegisterObject
from ._models_py3 import MetastoreRegistrationResponse
from ._models_py3 import MetastoreRequestSuccessResponse
from ._models_py3 import MetastoreUpdateObject
from ._models_py3 import MetastoreUpdationResponse
from ._models_py3 import MicrosoftAccessLinkedService
from ._models_py3 import MicrosoftAccessSink
from ._models_py3 import MicrosoftAccessSource
from ._models_py3 import MicrosoftAccessTableDataset
from ._models_py3 import MongoDbAtlasCollectionDataset
from ._models_py3 import MongoDbAtlasLinkedService
from ._models_py3 import MongoDbAtlasSource
from ._models_py3 import MongoDbCollectionDataset
from ._models_py3 import MongoDbCursorMethodsProperties
from ._models_py3 import MongoDbLinkedService
from ._models_py3 import MongoDbSource
from ._models_py3 import MongoDbV2CollectionDataset
from ._models_py3 import MongoDbV2LinkedService
from ._models_py3 import MongoDbV2Source
from ._models_py3 import MultiplePipelineTrigger
from ._models_py3 import MySqlLinkedService
from ._models_py3 import MySqlSource
from ._models_py3 import MySqlTableDataset
from ._models_py3 import NetezzaLinkedService
from ._models_py3 import NetezzaPartitionSettings
from ._models_py3 import NetezzaSource
from ._models_py3 import NetezzaTableDataset
from ._models_py3 import Notebook
from ._models_py3 import NotebookCell
from ._models_py3 import NotebookCellOutputItem
from ._models_py3 import NotebookFolder
from ._models_py3 import NotebookKernelSpec
from ._models_py3 import NotebookLanguageInfo
from ._models_py3 import NotebookListResponse
from ._models_py3 import NotebookMetadata
from ._models_py3 import NotebookParameter
from ._models_py3 import NotebookResource
from ._models_py3 import NotebookSessionProperties
from ._models_py3 import ODataLinkedService
from ._models_py3 import ODataResourceDataset
from ._models_py3 import ODataSource
from ._models_py3 import OdbcLinkedService
from ._models_py3 import OdbcSink
from ._models_py3 import OdbcSource
from ._models_py3 import OdbcTableDataset
from ._models_py3 import Office365Dataset
from ._models_py3 import Office365LinkedService
from ._models_py3 import Office365Source
from ._models_py3 import OperationResult
from ._models_py3 import OracleLinkedService
from ._models_py3 import OraclePartitionSettings
from ._models_py3 import OracleServiceCloudLinkedService
from ._models_py3 import OracleServiceCloudObjectDataset
from ._models_py3 import OracleServiceCloudSource
from ._models_py3 import OracleSink
from ._models_py3 import OracleSource
from ._models_py3 import OracleTableDataset
from ._models_py3 import OrcDataset
from ._models_py3 import OrcFormat
from ._models_py3 import OrcSink
from ._models_py3 import OrcSource
from ._models_py3 import OrcWriteSettings
from ._models_py3 import OutputColumn
from ._models_py3 import ParameterSpecification
from ._models_py3 import ParquetDataset
from ._models_py3 import ParquetFormat
from ._models_py3 import ParquetReadSettings
from ._models_py3 import ParquetSink
from ._models_py3 import ParquetSource
from ._models_py3 import ParquetWriteSettings
from ._models_py3 import PaypalLinkedService
from ._models_py3 import PaypalObjectDataset
from ._models_py3 import PaypalSource
from ._models_py3 import PhoenixLinkedService
from ._models_py3 import PhoenixObjectDataset
from ._models_py3 import PhoenixSource
from ._models_py3 import PipelineFolder
from ._models_py3 import PipelineListResponse
from ._models_py3 import PipelineReference
from ._models_py3 import PipelineResource
from ._models_py3 import PipelineRun
from ._models_py3 import PipelineRunInvokedBy
from ._models_py3 import PipelineRunsQueryResponse
from ._models_py3 import PolybaseSettings
from ._models_py3 import PostgreSqlLinkedService
from ._models_py3 import PostgreSqlSource
from ._models_py3 import PostgreSqlTableDataset
from ._models_py3 import PostgreSqlV2LinkedService
from ._models_py3 import PostgreSqlV2Source
from ._models_py3 import PostgreSqlV2TableDataset
from ._models_py3 import PowerBIWorkspaceLinkedService
from ._models_py3 import PrestoLinkedService
from ._models_py3 import PrestoObjectDataset
from ._models_py3 import PrestoSource
from ._models_py3 import PrivateEndpoint
from ._models_py3 import PrivateEndpointConnection
from ._models_py3 import PrivateLinkServiceConnectionState
from ._models_py3 import ProxyResource
from ._models_py3 import PurviewConfiguration
from ._models_py3 import QueryDataFlowDebugSessionsResponse
from ._models_py3 import QueryTableStatusRequest
from ._models_py3 import QuickBooksLinkedService
from ._models_py3 import QuickBooksObjectDataset
from ._models_py3 import QuickBooksSource
from ._models_py3 import QuickbaseLinkedService
from ._models_py3 import RecurrenceSchedule
from ._models_py3 import RecurrenceScheduleOccurrence
from ._models_py3 import RedirectIncompatibleRowSettings
from ._models_py3 import RedshiftUnloadSettings
from ._models_py3 import RelationalSource
from ._models_py3 import RelationalTableDataset
from ._models_py3 import RerunTriggerListResponse
from ._models_py3 import RerunTriggerResource
from ._models_py3 import RerunTumblingWindowTrigger
from ._models_py3 import RerunTumblingWindowTriggerActionParameters
from ._models_py3 import Resource
from ._models_py3 import ResponsysLinkedService
from ._models_py3 import ResponsysObjectDataset
from ._models_py3 import ResponsysSource
from ._models_py3 import RestResourceDataset
from ._models_py3 import RestServiceLinkedService
from ._models_py3 import RestSink
from ._models_py3 import RestSource
from ._models_py3 import RetryPolicy
from ._models_py3 import RunFilterParameters
from ._models_py3 import RunNotebookError
from ._models_py3 import RunNotebookParameter
from ._models_py3 import RunNotebookRequest
from ._models_py3 import RunNotebookResponse
from ._models_py3 import RunNotebookResult
from ._models_py3 import RunNotebookSnapshot
from ._models_py3 import RunNotebookSnapshotResponse
from ._models_py3 import RunNotebookSnapshotResult
from ._models_py3 import RunNotebookSparkSessionOptions
from ._models_py3 import RunQueryFilter
from ._models_py3 import RunQueryOrderBy
from ._models_py3 import SSISAccessCredential
from ._models_py3 import SSISChildPackage
from ._models_py3 import SSISExecutionCredential
from ._models_py3 import SSISExecutionParameter
from ._models_py3 import SSISLogLocation
from ._models_py3 import SSISPackageLocation
from ._models_py3 import SSISPropertyOverride
from ._models_py3 import SalesforceLinkedService
from ._models_py3 import SalesforceMarketingCloudLinkedService
from ._models_py3 import SalesforceMarketingCloudObjectDataset
from ._models_py3 import SalesforceMarketingCloudSource
from ._models_py3 import SalesforceObjectDataset
from ._models_py3 import SalesforceServiceCloudLinkedService
from ._models_py3 import SalesforceServiceCloudObjectDataset
from ._models_py3 import SalesforceServiceCloudSink
from ._models_py3 import SalesforceServiceCloudSource
from ._models_py3 import SalesforceServiceCloudV2LinkedService
from ._models_py3 import SalesforceServiceCloudV2ObjectDataset
from ._models_py3 import SalesforceServiceCloudV2Sink
from ._models_py3 import SalesforceServiceCloudV2Source
from ._models_py3 import SalesforceSink
from ._models_py3 import SalesforceSource
from ._models_py3 import SalesforceV2LinkedService
from ._models_py3 import SalesforceV2ObjectDataset
from ._models_py3 import SalesforceV2Sink
from ._models_py3 import SalesforceV2Source
from ._models_py3 import SapBWLinkedService
from ._models_py3 import SapBwCubeDataset
from ._models_py3 import SapBwSource
from ._models_py3 import SapCloudForCustomerLinkedService
from ._models_py3 import SapCloudForCustomerResourceDataset
from ._models_py3 import SapCloudForCustomerSink
from ._models_py3 import SapCloudForCustomerSource
from ._models_py3 import SapEccLinkedService
from ._models_py3 import SapEccResourceDataset
from ._models_py3 import SapEccSource
from ._models_py3 import SapHanaLinkedService
from ._models_py3 import SapHanaPartitionSettings
from ._models_py3 import SapHanaSource
from ._models_py3 import SapHanaTableDataset
from ._models_py3 import SapOdpLinkedService
from ._models_py3 import SapOdpResourceDataset
from ._models_py3 import SapOdpSource
from ._models_py3 import SapOpenHubLinkedService
from ._models_py3 import SapOpenHubSource
from ._models_py3 import SapOpenHubTableDataset
from ._models_py3 import SapTableLinkedService
from ._models_py3 import SapTablePartitionSettings
from ._models_py3 import SapTableResourceDataset
from ._models_py3 import SapTableSource
from ._models_py3 import ScheduleTrigger
from ._models_py3 import ScheduleTriggerRecurrence
from ._models_py3 import ScriptAction
from ._models_py3 import ScriptActivity
from ._models_py3 import ScriptActivityParameter
from ._models_py3 import ScriptActivityScriptBlock
from ._models_py3 import ScriptActivityTypePropertiesLogSettings
from ._models_py3 import SecretBase
from ._models_py3 import SecureInputOutputPolicy
from ._models_py3 import SecureString
from ._models_py3 import SelfDependencyTumblingWindowTriggerReference
from ._models_py3 import SelfHostedIntegrationRuntime
from ._models_py3 import ServiceNowLinkedService
from ._models_py3 import ServiceNowObjectDataset
from ._models_py3 import ServiceNowSource
from ._models_py3 import ServiceNowV2LinkedService
from ._models_py3 import ServiceNowV2ObjectDataset
from ._models_py3 import ServiceNowV2Source
from ._models_py3 import SetVariableActivity
from ._models_py3 import SftpLocation
from ._models_py3 import SftpReadSettings
from ._models_py3 import SftpServerLinkedService
from ._models_py3 import SftpWriteSettings
from ._models_py3 import SharePointOnlineListLinkedService
from ._models_py3 import SharePointOnlineListResourceDataset
from ._models_py3 import SharePointOnlineListSource
from ._models_py3 import ShopifyLinkedService
from ._models_py3 import ShopifyObjectDataset
from ._models_py3 import ShopifySource
from ._models_py3 import SkipErrorFile
from ._models_py3 import Sku
from ._models_py3 import SmartsheetLinkedService
from ._models_py3 import SnowflakeDataset
from ._models_py3 import SnowflakeExportCopyCommand
from ._models_py3 import SnowflakeImportCopyCommand
from ._models_py3 import SnowflakeLinkedService
from ._models_py3 import SnowflakeSink
from ._models_py3 import SnowflakeSource
from ._models_py3 import SnowflakeV2Dataset
from ._models_py3 import SnowflakeV2LinkedService
from ._models_py3 import SnowflakeV2Sink
from ._models_py3 import SnowflakeV2Source
from ._models_py3 import SparkBatchJob
from ._models_py3 import SparkBatchJobState
from ._models_py3 import SparkConfiguration
from ._models_py3 import SparkConfigurationListResponse
from ._models_py3 import SparkConfigurationParametrizationReference
from ._models_py3 import SparkConfigurationReference
from ._models_py3 import SparkConfigurationResource
from ._models_py3 import SparkJobDefinition
from ._models_py3 import SparkJobDefinitionFolder
from ._models_py3 import SparkJobDefinitionResource
from ._models_py3 import SparkJobDefinitionsListResponse
from ._models_py3 import SparkJobProperties
from ._models_py3 import SparkLinkedService
from ._models_py3 import SparkObjectDataset
from ._models_py3 import SparkRequest
from ._models_py3 import SparkScheduler
from ._models_py3 import SparkServiceError
from ._models_py3 import SparkServicePlugin
from ._models_py3 import SparkSource
from ._models_py3 import SqlAlwaysEncryptedProperties
from ._models_py3 import SqlConnection
from ._models_py3 import SqlDWSink
from ._models_py3 import SqlDWSource
from ._models_py3 import SqlMISink
from ._models_py3 import SqlMISource
from ._models_py3 import SqlPartitionSettings
from ._models_py3 import SqlPool
from ._models_py3 import SqlPoolInfoListResult
from ._models_py3 import SqlPoolReference
from ._models_py3 import SqlPoolStoredProcedureActivity
from ._models_py3 import SqlScript
from ._models_py3 import SqlScriptContent
from ._models_py3 import SqlScriptFolder
from ._models_py3 import SqlScriptMetadata
from ._models_py3 import SqlScriptResource
from ._models_py3 import SqlScriptsListResponse
from ._models_py3 import SqlServerBaseLinkedServiceTypeProperties
from ._models_py3 import SqlServerLinkedService
from ._models_py3 import SqlServerLinkedServiceTypeProperties
from ._models_py3 import SqlServerSink
from ._models_py3 import SqlServerSource
from ._models_py3 import SqlServerStoredProcedureActivity
from ._models_py3 import SqlServerTableDataset
from ._models_py3 import SqlSink
from ._models_py3 import SqlSource
from ._models_py3 import SquareLinkedService
from ._models_py3 import SquareObjectDataset
from ._models_py3 import SquareSource
from ._models_py3 import SsisObjectMetadataStatusResponse
from ._models_py3 import StagingSettings
from ._models_py3 import StartDataFlowDebugSessionRequest
from ._models_py3 import StartDataFlowDebugSessionResponse
from ._models_py3 import StoreReadSettings
from ._models_py3 import StoreWriteSettings
from ._models_py3 import StoredProcedureParameter
from ._models_py3 import SubResource
from ._models_py3 import SubResourceDebugResource
from ._models_py3 import SwitchActivity
from ._models_py3 import SwitchCase
from ._models_py3 import SybaseLinkedService
from ._models_py3 import SybaseSource
from ._models_py3 import SybaseTableDataset
from ._models_py3 import SynapseActivityAuthentication
from ._models_py3 import SynapseNotebookActivity
from ._models_py3 import SynapseNotebookReference
from ._models_py3 import SynapseSparkJobDefinitionActivity
from ._models_py3 import SynapseSparkJobReference
from ._models_py3 import TabularSource
from ._models_py3 import TabularTranslator
from ._models_py3 import TarGZipReadSettings
from ._models_py3 import TarReadSettings
from ._models_py3 import TeamDeskLinkedService
from ._models_py3 import TeradataImportCommand
from ._models_py3 import TeradataLinkedService
from ._models_py3 import TeradataPartitionSettings
from ._models_py3 import TeradataSink
from ._models_py3 import TeradataSource
from ._models_py3 import TeradataTableDataset
from ._models_py3 import TextFormat
from ._models_py3 import TrackedResource
from ._models_py3 import Transformation
from ._models_py3 import Trigger
from ._models_py3 import TriggerDependencyProvisioningStatus
from ._models_py3 import TriggerDependencyReference
from ._models_py3 import TriggerListResponse
from ._models_py3 import TriggerPipelineReference
from ._models_py3 import TriggerReference
from ._models_py3 import TriggerResource
from ._models_py3 import TriggerRun
from ._models_py3 import TriggerRunsQueryResponse
from ._models_py3 import TriggerSubscriptionOperationStatus
from ._models_py3 import TumblingWindowTrigger
from ._models_py3 import TumblingWindowTriggerDependencyReference
from ._models_py3 import TwilioLinkedService
from ._models_py3 import TypeConversionSettings
from ._models_py3 import UntilActivity
from ._models_py3 import UpdateLandingZoneCredential
from ._models_py3 import UserProperty
from ._models_py3 import ValidationActivity
from ._models_py3 import VariableSpecification
from ._models_py3 import VerticaLinkedService
from ._models_py3 import VerticaSource
from ._models_py3 import VerticaTableDataset
from ._models_py3 import VirtualNetworkProfile
from ._models_py3 import WaitActivity
from ._models_py3 import WarehouseLinkedService
from ._models_py3 import WarehouseSink
from ._models_py3 import WarehouseSource
from ._models_py3 import WarehouseTableDataset
from ._models_py3 import WebActivity
from ._models_py3 import WebActivityAuthentication
from ._models_py3 import WebAnonymousAuthentication
from ._models_py3 import WebBasicAuthentication
from ._models_py3 import WebClientCertificateAuthentication
from ._models_py3 import WebHookActivity
from ._models_py3 import WebLinkedService
from ._models_py3 import WebLinkedServiceTypeProperties
from ._models_py3 import WebSource
from ._models_py3 import WebTableDataset
from ._models_py3 import Workspace
from ._models_py3 import WorkspaceIdentity
from ._models_py3 import WorkspaceKeyDetails
from ._models_py3 import WorkspaceRepositoryConfiguration
from ._models_py3 import WorkspaceUpdateParameters
from ._models_py3 import XeroLinkedService
from ._models_py3 import XeroObjectDataset
from ._models_py3 import XeroSource
from ._models_py3 import XmlDataset
from ._models_py3 import XmlReadSettings
from ._models_py3 import XmlSource
from ._models_py3 import ZendeskLinkedService
from ._models_py3 import ZipDeflateReadSettings
from ._models_py3 import ZohoLinkedService
from ._models_py3 import ZohoObjectDataset
from ._models_py3 import ZohoSource

from ._artifacts_client_enums import ActionOnExistingTargetTable
from ._artifacts_client_enums import ActivityOnInactiveMarkAs
from ._artifacts_client_enums import ActivityState
from ._artifacts_client_enums import AmazonRdsForOracleAuthenticationType
from ._artifacts_client_enums import AmazonRdsForOraclePartitionOption
from ._artifacts_client_enums import AmazonRdsForSqlServerAuthenticationType
from ._artifacts_client_enums import AvroCompressionCodec
from ._artifacts_client_enums import AzureFunctionActivityMethod
from ._artifacts_client_enums import AzurePostgreSqlWriteMethodEnum
from ._artifacts_client_enums import AzureSearchIndexWriteBehaviorType
from ._artifacts_client_enums import AzureSqlDWAuthenticationType
from ._artifacts_client_enums import AzureSqlDatabaseAuthenticationType
from ._artifacts_client_enums import AzureSqlMIAuthenticationType
from ._artifacts_client_enums import AzureStorageAuthenticationType
from ._artifacts_client_enums import BigDataPoolReferenceType
from ._artifacts_client_enums import BlobEventType
from ._artifacts_client_enums import CassandraSourceReadConsistencyLevels
from ._artifacts_client_enums import CellOutputType
from ._artifacts_client_enums import CompressionCodec
from ._artifacts_client_enums import ConfigurationType
from ._artifacts_client_enums import CopyBehaviorType
from ._artifacts_client_enums import CreateMode
from ._artifacts_client_enums import CredentialReferenceType
from ._artifacts_client_enums import DataFlowComputeType
from ._artifacts_client_enums import DataFlowDebugCommandType
from ._artifacts_client_enums import DataFlowReferenceType
from ._artifacts_client_enums import DatasetCompressionLevel
from ._artifacts_client_enums import DatasetReferenceType
from ._artifacts_client_enums import DayOfWeek
from ._artifacts_client_enums import Db2AuthenticationType
from ._artifacts_client_enums import DependencyCondition
from ._artifacts_client_enums import DynamicsAuthenticationType
from ._artifacts_client_enums import DynamicsDeploymentType
from ._artifacts_client_enums import DynamicsServicePrincipalCredentialType
from ._artifacts_client_enums import DynamicsSinkWriteBehavior
from ._artifacts_client_enums import Enum13
from ._artifacts_client_enums import EventSubscriptionStatus
from ._artifacts_client_enums import ExpressionType
from ._artifacts_client_enums import ExpressionV2Type
from ._artifacts_client_enums import FtpAuthenticationType
from ._artifacts_client_enums import GoogleAdWordsAuthenticationType
from ._artifacts_client_enums import GoogleBigQueryAuthenticationType
from ._artifacts_client_enums import GoogleBigQueryV2AuthenticationType
from ._artifacts_client_enums import GreenplumAuthenticationType
from ._artifacts_client_enums import HBaseAuthenticationType
from ._artifacts_client_enums import HDInsightActivityDebugInfoOption
from ._artifacts_client_enums import HDInsightClusterAuthenticationType
from ._artifacts_client_enums import HdiNodeTypes
from ._artifacts_client_enums import HiveAuthenticationType
from ._artifacts_client_enums import HiveServerType
from ._artifacts_client_enums import HiveThriftTransportProtocol
from ._artifacts_client_enums import HttpAuthenticationType
from ._artifacts_client_enums import ImpalaAuthenticationType
from ._artifacts_client_enums import ImpalaThriftTransportProtocol
from ._artifacts_client_enums import IntegrationRuntimeEdition
from ._artifacts_client_enums import IntegrationRuntimeEntityReferenceType
from ._artifacts_client_enums import IntegrationRuntimeLicenseType
from ._artifacts_client_enums import IntegrationRuntimeReferenceType
from ._artifacts_client_enums import IntegrationRuntimeSsisCatalogPricingTier
from ._artifacts_client_enums import IntegrationRuntimeState
from ._artifacts_client_enums import IntegrationRuntimeType
from ._artifacts_client_enums import JsonFormatFilePattern
from ._artifacts_client_enums import JsonWriteFilePattern
from ._artifacts_client_enums import LakehouseAuthenticationType
from ._artifacts_client_enums import LivyStates
from ._artifacts_client_enums import ManagedVirtualNetworkReferenceType
from ._artifacts_client_enums import MongoDbAuthenticationType
from ._artifacts_client_enums import NetezzaPartitionOption
from ._artifacts_client_enums import NodeSize
from ._artifacts_client_enums import NodeSizeFamily
from ._artifacts_client_enums import NotebookParameterType
from ._artifacts_client_enums import NotebookReferenceType
from ._artifacts_client_enums import ODataAadServicePrincipalCredentialType
from ._artifacts_client_enums import ODataAuthenticationType
from ._artifacts_client_enums import OracleAuthenticationType
from ._artifacts_client_enums import OraclePartitionOption
from ._artifacts_client_enums import OrcCompressionCodec
from ._artifacts_client_enums import ParameterType
from ._artifacts_client_enums import ParquetCompressionCodecEnum
from ._artifacts_client_enums import PhoenixAuthenticationType
from ._artifacts_client_enums import PipelineReferenceType
from ._artifacts_client_enums import PluginCurrentState
from ._artifacts_client_enums import PolybaseSettingsRejectType
from ._artifacts_client_enums import PrestoAuthenticationType
from ._artifacts_client_enums import RecurrenceFrequency
from ._artifacts_client_enums import RequestStatus
from ._artifacts_client_enums import ResourceIdentityType
from ._artifacts_client_enums import ResourceStatus
from ._artifacts_client_enums import RestServiceAuthenticationType
from ._artifacts_client_enums import RunQueryFilterOperand
from ._artifacts_client_enums import RunQueryFilterOperator
from ._artifacts_client_enums import RunQueryOrder
from ._artifacts_client_enums import RunQueryOrderByField
from ._artifacts_client_enums import SalesforceSinkWriteBehavior
from ._artifacts_client_enums import SalesforceSourceReadBehavior
from ._artifacts_client_enums import SalesforceV2SinkWriteBehavior
from ._artifacts_client_enums import SapCloudForCustomerSinkWriteBehavior
from ._artifacts_client_enums import SapHanaAuthenticationType
from ._artifacts_client_enums import SapHanaPartitionOption
from ._artifacts_client_enums import SapTablePartitionOption
from ._artifacts_client_enums import SchedulerCurrentState
from ._artifacts_client_enums import ScriptActivityLogDestination
from ._artifacts_client_enums import ScriptActivityParameterDirection
from ._artifacts_client_enums import ScriptActivityParameterType
from ._artifacts_client_enums import ScriptType
from ._artifacts_client_enums import ServiceNowAuthenticationType
from ._artifacts_client_enums import ServiceNowV2AuthenticationType
from ._artifacts_client_enums import SftpAuthenticationType
from ._artifacts_client_enums import SnowflakeAuthenticationType
from ._artifacts_client_enums import SparkAuthenticationType
from ._artifacts_client_enums import SparkBatchJobResultType
from ._artifacts_client_enums import SparkConfigurationReferenceType
from ._artifacts_client_enums import SparkErrorSource
from ._artifacts_client_enums import SparkJobReferenceType
from ._artifacts_client_enums import SparkJobType
from ._artifacts_client_enums import SparkServerType
from ._artifacts_client_enums import SparkThriftTransportProtocol
from ._artifacts_client_enums import SqlAlwaysEncryptedAkvAuthType
from ._artifacts_client_enums import SqlConnectionType
from ._artifacts_client_enums import SqlPartitionOption
from ._artifacts_client_enums import SqlPoolReferenceType
from ._artifacts_client_enums import SqlScriptType
from ._artifacts_client_enums import SqlServerAuthenticationType
from ._artifacts_client_enums import SsisLogLocationType
from ._artifacts_client_enums import SsisPackageLocationType
from ._artifacts_client_enums import StoredProcedureParameterType
from ._artifacts_client_enums import SybaseAuthenticationType
from ._artifacts_client_enums import TeamDeskAuthenticationType
from ._artifacts_client_enums import TeradataAuthenticationType
from ._artifacts_client_enums import TeradataPartitionOption
from ._artifacts_client_enums import TriggerReferenceType
from ._artifacts_client_enums import TriggerRunStatus
from ._artifacts_client_enums import TriggerRuntimeState
from ._artifacts_client_enums import TumblingWindowFrequency
from ._artifacts_client_enums import Type
from ._artifacts_client_enums import ValueType
from ._artifacts_client_enums import VariableType
from ._artifacts_client_enums import WarehouseAuthenticationType
from ._artifacts_client_enums import WebActivityMethod
from ._artifacts_client_enums import WebAuthenticationType
from ._artifacts_client_enums import WebHookActivityMethod
from ._artifacts_client_enums import ZendeskAuthenticationType
from ._patch import __all__ as _patch_all
from ._patch import *  # pylint: disable=unused-wildcard-import
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Activity",
    "ActivityDependency",
    "ActivityPolicy",
    "ActivityRun",
    "ActivityRunsQueryResponse",
    "AddDataFlowToDebugSessionResponse",
    "AdditionalColumns",
    "AmazonMWSLinkedService",
    "AmazonMWSObjectDataset",
    "AmazonMWSSource",
    "AmazonRdsForOracleLinkedService",
    "AmazonRdsForOraclePartitionSettings",
    "AmazonRdsForOracleSource",
    "AmazonRdsForOracleTableDataset",
    "AmazonRdsForSqlServerLinkedService",
    "AmazonRdsForSqlServerLinkedServiceTypeProperties",
    "AmazonRdsForSqlServerSource",
    "AmazonRdsForSqlServerTableDataset",
    "AmazonRedshiftLinkedService",
    "AmazonRedshiftSource",
    "AmazonRedshiftTableDataset",
    "AmazonS3Dataset",
    "AmazonS3LinkedService",
    "AmazonS3Location",
    "AmazonS3ReadSettings",
    "AppFiguresLinkedService",
    "AppendVariableActivity",
    "ArtifactRenameRequest",
    "AsanaLinkedService",
    "AutoPauseProperties",
    "AutoScaleProperties",
    "AvroDataset",
    "AvroFormat",
    "AvroSink",
    "AvroSource",
    "AvroWriteSettings",
    "AzureBatchLinkedService",
    "AzureBlobDataset",
    "AzureBlobFSDataset",
    "AzureBlobFSLinkedService",
    "AzureBlobFSLocation",
    "AzureBlobFSReadSettings",
    "AzureBlobFSSink",
    "AzureBlobFSSource",
    "AzureBlobFSWriteSettings",
    "AzureBlobStorageLinkedService",
    "AzureBlobStorageLocation",
    "AzureBlobStorageReadSettings",
    "AzureBlobStorageWriteSettings",
    "AzureDataExplorerCommandActivity",
    "AzureDataExplorerLinkedService",
    "AzureDataExplorerSink",
    "AzureDataExplorerSource",
    "AzureDataExplorerTableDataset",
    "AzureDataLakeAnalyticsLinkedService",
    "AzureDataLakeStoreDataset",
    "AzureDataLakeStoreLinkedService",
    "AzureDataLakeStoreLocation",
    "AzureDataLakeStoreReadSettings",
    "AzureDataLakeStoreSink",
    "AzureDataLakeStoreSource",
    "AzureDataLakeStoreWriteSettings",
    "AzureDatabricksDeltaLakeDataset",
    "AzureDatabricksDeltaLakeExportCommand",
    "AzureDatabricksDeltaLakeImportCommand",
    "AzureDatabricksDeltaLakeLinkedService",
    "AzureDatabricksDeltaLakeSink",
    "AzureDatabricksDeltaLakeSource",
    "AzureDatabricksLinkedService",
    "AzureEntityResource",
    "AzureFileStorageLinkedService",
    "AzureFileStorageLocation",
    "AzureFileStorageReadSettings",
    "AzureFileStorageWriteSettings",
    "AzureFunctionActivity",
    "AzureFunctionLinkedService",
    "AzureKeyVaultLinkedService",
    "AzureKeyVaultSecretReference",
    "AzureMLBatchExecutionActivity",
    "AzureMLExecutePipelineActivity",
    "AzureMLLinkedService",
    "AzureMLServiceLinkedService",
    "AzureMLUpdateResourceActivity",
    "AzureMLWebServiceFile",
    "AzureMariaDBLinkedService",
    "AzureMariaDBSource",
    "AzureMariaDBTableDataset",
    "AzureMySqlLinkedService",
    "AzureMySqlSink",
    "AzureMySqlSource",
    "AzureMySqlTableDataset",
    "AzurePostgreSqlLinkedService",
    "AzurePostgreSqlSink",
    "AzurePostgreSqlSinkUpsertSettings",
    "AzurePostgreSqlSource",
    "AzurePostgreSqlTableDataset",
    "AzureQueueSink",
    "AzureSearchIndexDataset",
    "AzureSearchIndexSink",
    "AzureSearchLinkedService",
    "AzureSqlDWLinkedService",
    "AzureSqlDWLinkedServiceTypeProperties",
    "AzureSqlDWTableDataset",
    "AzureSqlDatabaseLinkedService",
    "AzureSqlDatabaseLinkedServiceTypeProperties",
    "AzureSqlMILinkedService",
    "AzureSqlMILinkedServiceTypeProperties",
    "AzureSqlMITableDataset",
    "AzureSqlSink",
    "AzureSqlSource",
    "AzureSqlTableDataset",
    "AzureStorageLinkedService",
    "AzureStorageLinkedServiceTypeProperties",
    "AzureSynapseArtifactsLinkedService",
    "AzureTableDataset",
    "AzureTableSink",
    "AzureTableSource",
    "AzureTableStorageLinkedService",
    "AzureTableStorageLinkedServiceTypeProperties",
    "BigDataPoolParametrizationReference",
    "BigDataPoolReference",
    "BigDataPoolResourceInfo",
    "BigDataPoolResourceInfoListResult",
    "BinaryDataset",
    "BinaryReadSettings",
    "BinarySink",
    "BinarySource",
    "BlobEventsTrigger",
    "BlobSink",
    "BlobSource",
    "BlobTrigger",
    "CassandraLinkedService",
    "CassandraSource",
    "CassandraTableDataset",
    "ChainingTrigger",
    "CloudError",
    "CommonDataServiceForAppsEntityDataset",
    "CommonDataServiceForAppsLinkedService",
    "CommonDataServiceForAppsSink",
    "CommonDataServiceForAppsSource",
    "CompressionReadSettings",
    "ConcurLinkedService",
    "ConcurObjectDataset",
    "ConcurSource",
    "ContinuationSettingsReference",
    "ControlActivity",
    "CopyActivity",
    "CopyActivityLogSettings",
    "CopySink",
    "CopySource",
    "CopyTranslator",
    "CosmosDbLinkedService",
    "CosmosDbMongoDbApiCollectionDataset",
    "CosmosDbMongoDbApiLinkedService",
    "CosmosDbMongoDbApiSink",
    "CosmosDbMongoDbApiSource",
    "CosmosDbSqlApiCollectionDataset",
    "CosmosDbSqlApiSink",
    "CosmosDbSqlApiSource",
    "CouchbaseLinkedService",
    "CouchbaseSource",
    "CouchbaseTableDataset",
    "CreateDataFlowDebugSessionRequest",
    "CreateDataFlowDebugSessionResponse",
    "CreateRunResponse",
    "CredentialReference",
    "CustomActivity",
    "CustomActivityReferenceObject",
    "CustomDataSourceLinkedService",
    "CustomDataset",
    "CustomEventsTrigger",
    "CustomSetupBase",
    "CustomerManagedKeyDetails",
    "DWCopyCommandDefaultValue",
    "DWCopyCommandSettings",
    "DataFlow",
    "DataFlowDebugCommandPayload",
    "DataFlowDebugCommandRequest",
    "DataFlowDebugCommandResponse",
    "DataFlowDebugPackage",
    "DataFlowDebugPackageDebugSettings",
    "DataFlowDebugPreviewDataRequest",
    "DataFlowDebugQueryResponse",
    "DataFlowDebugResource",
    "DataFlowDebugResultResponse",
    "DataFlowDebugSessionInfo",
    "DataFlowDebugStatisticsRequest",
    "DataFlowFolder",
    "DataFlowListResponse",
    "DataFlowReference",
    "DataFlowResource",
    "DataFlowSink",
    "DataFlowSource",
    "DataFlowSourceSetting",
    "DataFlowStagingInfo",
    "DataLakeAnalyticsUSQLActivity",
    "DataLakeStorageAccountDetails",
    "DatabricksNotebookActivity",
    "DatabricksSparkJarActivity",
    "DatabricksSparkPythonActivity",
    "Dataset",
    "DatasetCompression",
    "DatasetDataElement",
    "DatasetDebugResource",
    "DatasetFolder",
    "DatasetListResponse",
    "DatasetLocation",
    "DatasetReference",
    "DatasetResource",
    "DatasetSchemaDataElement",
    "DatasetStorageFormat",
    "DataworldLinkedService",
    "Db2LinkedService",
    "Db2Source",
    "Db2TableDataset",
    "DeleteActivity",
    "DeleteDataFlowDebugSessionRequest",
    "DelimitedTextDataset",
    "DelimitedTextReadSettings",
    "DelimitedTextSink",
    "DelimitedTextSource",
    "DelimitedTextWriteSettings",
    "DependencyReference",
    "DistcpSettings",
    "DocumentDbCollectionDataset",
    "DocumentDbCollectionSink",
    "DocumentDbCollectionSource",
    "DrillLinkedService",
    "DrillSource",
    "DrillTableDataset",
    "DynamicExecutorAllocation",
    "DynamicsAXLinkedService",
    "DynamicsAXResourceDataset",
    "DynamicsAXSource",
    "DynamicsCrmEntityDataset",
    "DynamicsCrmLinkedService",
    "DynamicsCrmSink",
    "DynamicsCrmSource",
    "DynamicsEntityDataset",
    "DynamicsLinkedService",
    "DynamicsSink",
    "DynamicsSource",
    "EditTablesRequest",
    "EloquaLinkedService",
    "EloquaObjectDataset",
    "EloquaSource",
    "EncryptionDetails",
    "EntityReference",
    "ErrorAdditionalInfo",
    "ErrorContract",
    "ErrorResponse",
    "EvaluateDataFlowExpressionRequest",
    "ExcelDataset",
    "ExcelSource",
    "ExecuteDataFlowActivity",
    "ExecuteDataFlowActivityTypePropertiesCompute",
    "ExecutePipelineActivity",
    "ExecuteSSISPackageActivity",
    "ExecutionActivity",
    "ExportSettings",
    "ExposureControlRequest",
    "ExposureControlResponse",
    "Expression",
    "ExpressionV2",
    "FailActivity",
    "FileServerLinkedService",
    "FileServerLocation",
    "FileServerReadSettings",
    "FileServerWriteSettings",
    "FileShareDataset",
    "FileSystemSink",
    "FileSystemSource",
    "FilterActivity",
    "Flowlet",
    "ForEachActivity",
    "FormatReadSettings",
    "FormatWriteSettings",
    "FtpReadSettings",
    "FtpServerLinkedService",
    "FtpServerLocation",
    "GetMetadataActivity",
    "GetSsisObjectMetadataRequest",
    "GitHubAccessTokenRequest",
    "GitHubAccessTokenResponse",
    "GitHubClientSecret",
    "GoogleAdWordsLinkedService",
    "GoogleAdWordsObjectDataset",
    "GoogleAdWordsSource",
    "GoogleBigQueryLinkedService",
    "GoogleBigQueryObjectDataset",
    "GoogleBigQuerySource",
    "GoogleBigQueryV2LinkedService",
    "GoogleBigQueryV2ObjectDataset",
    "GoogleBigQueryV2Source",
    "GoogleCloudStorageLinkedService",
    "GoogleCloudStorageLocation",
    "GoogleCloudStorageReadSettings",
    "GoogleSheetsLinkedService",
    "GreenplumLinkedService",
    "GreenplumSource",
    "GreenplumTableDataset",
    "HBaseLinkedService",
    "HBaseObjectDataset",
    "HBaseSource",
    "HDInsightHiveActivity",
    "HDInsightLinkedService",
    "HDInsightMapReduceActivity",
    "HDInsightOnDemandLinkedService",
    "HDInsightPigActivity",
    "HDInsightSparkActivity",
    "HDInsightStreamingActivity",
    "HdfsLinkedService",
    "HdfsLocation",
    "HdfsReadSettings",
    "HdfsSource",
    "HiveLinkedService",
    "HiveObjectDataset",
    "HiveSource",
    "HttpDataset",
    "HttpLinkedService",
    "HttpReadSettings",
    "HttpServerLocation",
    "HttpSource",
    "HubspotLinkedService",
    "HubspotObjectDataset",
    "HubspotSource",
    "IcebergDataset",
    "IcebergSink",
    "IcebergWriteSettings",
    "IfConditionActivity",
    "ImpalaLinkedService",
    "ImpalaObjectDataset",
    "ImpalaSource",
    "ImportSettings",
    "InformixLinkedService",
    "InformixSink",
    "InformixSource",
    "InformixTableDataset",
    "IntegrationRuntime",
    "IntegrationRuntimeComputeProperties",
    "IntegrationRuntimeCustomSetupScriptProperties",
    "IntegrationRuntimeDataFlowProperties",
    "IntegrationRuntimeDataProxyProperties",
    "IntegrationRuntimeDebugResource",
    "IntegrationRuntimeListResponse",
    "IntegrationRuntimeReference",
    "IntegrationRuntimeResource",
    "IntegrationRuntimeSsisCatalogInfo",
    "IntegrationRuntimeSsisProperties",
    "IntegrationRuntimeVNetProperties",
    "JiraLinkedService",
    "JiraObjectDataset",
    "JiraSource",
    "JsonDataset",
    "JsonFormat",
    "JsonReadSettings",
    "JsonSink",
    "JsonSource",
    "JsonWriteSettings",
    "KqlScript",
    "KqlScriptContent",
    "KqlScriptContentCurrentConnection",
    "KqlScriptContentMetadata",
    "KqlScriptResource",
    "KqlScriptsResourceCollectionResponse",
    "LakeHouseLinkedService",
    "LakeHouseLocation",
    "LakeHouseReadSettings",
    "LakeHouseTableDataset",
    "LakeHouseTableSink",
    "LakeHouseTableSource",
    "LakeHouseWriteSettings",
    "LibraryInfo",
    "LibraryListResponse",
    "LibraryRequirements",
    "LibraryResource",
    "LibraryResourceInfo",
    "LibraryResourceProperties",
    "LinkConnection",
    "LinkConnectionCompute",
    "LinkConnectionDetailedStatus",
    "LinkConnectionLandingZone",
    "LinkConnectionListResponse",
    "LinkConnectionQueryTableStatus",
    "LinkConnectionRefreshStatus",
    "LinkConnectionResource",
    "LinkConnectionSourceDatabase",
    "LinkConnectionSourceDatabaseTypeProperties",
    "LinkConnectionTargetDatabase",
    "LinkConnectionTargetDatabaseTypeProperties",
    "LinkTableListResponse",
    "LinkTableRequest",
    "LinkTableRequestSource",
    "LinkTableRequestTarget",
    "LinkTableRequestTargetDistributionOptions",
    "LinkTableRequestTargetStructureOptions",
    "LinkTableResource",
    "LinkTableStatus",
    "LinkedIntegrationRuntimeKeyAuthorization",
    "LinkedIntegrationRuntimeRbacAuthorization",
    "LinkedIntegrationRuntimeType",
    "LinkedService",
    "LinkedServiceDebugResource",
    "LinkedServiceListResponse",
    "LinkedServiceReference",
    "LinkedServiceResource",
    "LogLocationSettings",
    "LogSettings",
    "LogStorageSettings",
    "LookupActivity",
    "MagentoLinkedService",
    "MagentoObjectDataset",
    "MagentoSource",
    "ManagedIdentity",
    "ManagedIntegrationRuntime",
    "ManagedVirtualNetworkReference",
    "ManagedVirtualNetworkSettings",
    "MappingDataFlow",
    "MariaDBLinkedService",
    "MariaDBSource",
    "MariaDBTableDataset",
    "MarketoLinkedService",
    "MarketoObjectDataset",
    "MarketoSource",
    "MetadataItem",
    "MetastoreRegisterObject",
    "MetastoreRegistrationResponse",
    "MetastoreRequestSuccessResponse",
    "MetastoreUpdateObject",
    "MetastoreUpdationResponse",
    "MicrosoftAccessLinkedService",
    "MicrosoftAccessSink",
    "MicrosoftAccessSource",
    "MicrosoftAccessTableDataset",
    "MongoDbAtlasCollectionDataset",
    "MongoDbAtlasLinkedService",
    "MongoDbAtlasSource",
    "MongoDbCollectionDataset",
    "MongoDbCursorMethodsProperties",
    "MongoDbLinkedService",
    "MongoDbSource",
    "MongoDbV2CollectionDataset",
    "MongoDbV2LinkedService",
    "MongoDbV2Source",
    "MultiplePipelineTrigger",
    "MySqlLinkedService",
    "MySqlSource",
    "MySqlTableDataset",
    "NetezzaLinkedService",
    "NetezzaPartitionSettings",
    "NetezzaSource",
    "NetezzaTableDataset",
    "Notebook",
    "NotebookCell",
    "NotebookCellOutputItem",
    "NotebookFolder",
    "NotebookKernelSpec",
    "NotebookLanguageInfo",
    "NotebookListResponse",
    "NotebookMetadata",
    "NotebookParameter",
    "NotebookResource",
    "NotebookSessionProperties",
    "ODataLinkedService",
    "ODataResourceDataset",
    "ODataSource",
    "OdbcLinkedService",
    "OdbcSink",
    "OdbcSource",
    "OdbcTableDataset",
    "Office365Dataset",
    "Office365LinkedService",
    "Office365Source",
    "OperationResult",
    "OracleLinkedService",
    "OraclePartitionSettings",
    "OracleServiceCloudLinkedService",
    "OracleServiceCloudObjectDataset",
    "OracleServiceCloudSource",
    "OracleSink",
    "OracleSource",
    "OracleTableDataset",
    "OrcDataset",
    "OrcFormat",
    "OrcSink",
    "OrcSource",
    "OrcWriteSettings",
    "OutputColumn",
    "ParameterSpecification",
    "ParquetDataset",
    "ParquetFormat",
    "ParquetReadSettings",
    "ParquetSink",
    "ParquetSource",
    "ParquetWriteSettings",
    "PaypalLinkedService",
    "PaypalObjectDataset",
    "PaypalSource",
    "PhoenixLinkedService",
    "PhoenixObjectDataset",
    "PhoenixSource",
    "PipelineFolder",
    "PipelineListResponse",
    "PipelineReference",
    "PipelineResource",
    "PipelineRun",
    "PipelineRunInvokedBy",
    "PipelineRunsQueryResponse",
    "PolybaseSettings",
    "PostgreSqlLinkedService",
    "PostgreSqlSource",
    "PostgreSqlTableDataset",
    "PostgreSqlV2LinkedService",
    "PostgreSqlV2Source",
    "PostgreSqlV2TableDataset",
    "PowerBIWorkspaceLinkedService",
    "PrestoLinkedService",
    "PrestoObjectDataset",
    "PrestoSource",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateLinkServiceConnectionState",
    "ProxyResource",
    "PurviewConfiguration",
    "QueryDataFlowDebugSessionsResponse",
    "QueryTableStatusRequest",
    "QuickBooksLinkedService",
    "QuickBooksObjectDataset",
    "QuickBooksSource",
    "QuickbaseLinkedService",
    "RecurrenceSchedule",
    "RecurrenceScheduleOccurrence",
    "RedirectIncompatibleRowSettings",
    "RedshiftUnloadSettings",
    "RelationalSource",
    "RelationalTableDataset",
    "RerunTriggerListResponse",
    "RerunTriggerResource",
    "RerunTumblingWindowTrigger",
    "RerunTumblingWindowTriggerActionParameters",
    "Resource",
    "ResponsysLinkedService",
    "ResponsysObjectDataset",
    "ResponsysSource",
    "RestResourceDataset",
    "RestServiceLinkedService",
    "RestSink",
    "RestSource",
    "RetryPolicy",
    "RunFilterParameters",
    "RunNotebookError",
    "RunNotebookParameter",
    "RunNotebookRequest",
    "RunNotebookResponse",
    "RunNotebookResult",
    "RunNotebookSnapshot",
    "RunNotebookSnapshotResponse",
    "RunNotebookSnapshotResult",
    "RunNotebookSparkSessionOptions",
    "RunQueryFilter",
    "RunQueryOrderBy",
    "SSISAccessCredential",
    "SSISChildPackage",
    "SSISExecutionCredential",
    "SSISExecutionParameter",
    "SSISLogLocation",
    "SSISPackageLocation",
    "SSISPropertyOverride",
    "SalesforceLinkedService",
    "SalesforceMarketingCloudLinkedService",
    "SalesforceMarketingCloudObjectDataset",
    "SalesforceMarketingCloudSource",
    "SalesforceObjectDataset",
    "SalesforceServiceCloudLinkedService",
    "SalesforceServiceCloudObjectDataset",
    "SalesforceServiceCloudSink",
    "SalesforceServiceCloudSource",
    "SalesforceServiceCloudV2LinkedService",
    "SalesforceServiceCloudV2ObjectDataset",
    "SalesforceServiceCloudV2Sink",
    "SalesforceServiceCloudV2Source",
    "SalesforceSink",
    "SalesforceSource",
    "SalesforceV2LinkedService",
    "SalesforceV2ObjectDataset",
    "SalesforceV2Sink",
    "SalesforceV2Source",
    "SapBWLinkedService",
    "SapBwCubeDataset",
    "SapBwSource",
    "SapCloudForCustomerLinkedService",
    "SapCloudForCustomerResourceDataset",
    "SapCloudForCustomerSink",
    "SapCloudForCustomerSource",
    "SapEccLinkedService",
    "SapEccResourceDataset",
    "SapEccSource",
    "SapHanaLinkedService",
    "SapHanaPartitionSettings",
    "SapHanaSource",
    "SapHanaTableDataset",
    "SapOdpLinkedService",
    "SapOdpResourceDataset",
    "SapOdpSource",
    "SapOpenHubLinkedService",
    "SapOpenHubSource",
    "SapOpenHubTableDataset",
    "SapTableLinkedService",
    "SapTablePartitionSettings",
    "SapTableResourceDataset",
    "SapTableSource",
    "ScheduleTrigger",
    "ScheduleTriggerRecurrence",
    "ScriptAction",
    "ScriptActivity",
    "ScriptActivityParameter",
    "ScriptActivityScriptBlock",
    "ScriptActivityTypePropertiesLogSettings",
    "SecretBase",
    "SecureInputOutputPolicy",
    "SecureString",
    "SelfDependencyTumblingWindowTriggerReference",
    "SelfHostedIntegrationRuntime",
    "ServiceNowLinkedService",
    "ServiceNowObjectDataset",
    "ServiceNowSource",
    "ServiceNowV2LinkedService",
    "ServiceNowV2ObjectDataset",
    "ServiceNowV2Source",
    "SetVariableActivity",
    "SftpLocation",
    "SftpReadSettings",
    "SftpServerLinkedService",
    "SftpWriteSettings",
    "SharePointOnlineListLinkedService",
    "SharePointOnlineListResourceDataset",
    "SharePointOnlineListSource",
    "ShopifyLinkedService",
    "ShopifyObjectDataset",
    "ShopifySource",
    "SkipErrorFile",
    "Sku",
    "SmartsheetLinkedService",
    "SnowflakeDataset",
    "SnowflakeExportCopyCommand",
    "SnowflakeImportCopyCommand",
    "SnowflakeLinkedService",
    "SnowflakeSink",
    "SnowflakeSource",
    "SnowflakeV2Dataset",
    "SnowflakeV2LinkedService",
    "SnowflakeV2Sink",
    "SnowflakeV2Source",
    "SparkBatchJob",
    "SparkBatchJobState",
    "SparkConfiguration",
    "SparkConfigurationListResponse",
    "SparkConfigurationParametrizationReference",
    "SparkConfigurationReference",
    "SparkConfigurationResource",
    "SparkJobDefinition",
    "SparkJobDefinitionFolder",
    "SparkJobDefinitionResource",
    "SparkJobDefinitionsListResponse",
    "SparkJobProperties",
    "SparkLinkedService",
    "SparkObjectDataset",
    "SparkRequest",
    "SparkScheduler",
    "SparkServiceError",
    "SparkServicePlugin",
    "SparkSource",
    "SqlAlwaysEncryptedProperties",
    "SqlConnection",
    "SqlDWSink",
    "SqlDWSource",
    "SqlMISink",
    "SqlMISource",
    "SqlPartitionSettings",
    "SqlPool",
    "SqlPoolInfoListResult",
    "SqlPoolReference",
    "SqlPoolStoredProcedureActivity",
    "SqlScript",
    "SqlScriptContent",
    "SqlScriptFolder",
    "SqlScriptMetadata",
    "SqlScriptResource",
    "SqlScriptsListResponse",
    "SqlServerBaseLinkedServiceTypeProperties",
    "SqlServerLinkedService",
    "SqlServerLinkedServiceTypeProperties",
    "SqlServerSink",
    "SqlServerSource",
    "SqlServerStoredProcedureActivity",
    "SqlServerTableDataset",
    "SqlSink",
    "SqlSource",
    "SquareLinkedService",
    "SquareObjectDataset",
    "SquareSource",
    "SsisObjectMetadataStatusResponse",
    "StagingSettings",
    "StartDataFlowDebugSessionRequest",
    "StartDataFlowDebugSessionResponse",
    "StoreReadSettings",
    "StoreWriteSettings",
    "StoredProcedureParameter",
    "SubResource",
    "SubResourceDebugResource",
    "SwitchActivity",
    "SwitchCase",
    "SybaseLinkedService",
    "SybaseSource",
    "SybaseTableDataset",
    "SynapseActivityAuthentication",
    "SynapseNotebookActivity",
    "SynapseNotebookReference",
    "SynapseSparkJobDefinitionActivity",
    "SynapseSparkJobReference",
    "TabularSource",
    "TabularTranslator",
    "TarGZipReadSettings",
    "TarReadSettings",
    "TeamDeskLinkedService",
    "TeradataImportCommand",
    "TeradataLinkedService",
    "TeradataPartitionSettings",
    "TeradataSink",
    "TeradataSource",
    "TeradataTableDataset",
    "TextFormat",
    "TrackedResource",
    "Transformation",
    "Trigger",
    "TriggerDependencyProvisioningStatus",
    "TriggerDependencyReference",
    "TriggerListResponse",
    "TriggerPipelineReference",
    "TriggerReference",
    "TriggerResource",
    "TriggerRun",
    "TriggerRunsQueryResponse",
    "TriggerSubscriptionOperationStatus",
    "TumblingWindowTrigger",
    "TumblingWindowTriggerDependencyReference",
    "TwilioLinkedService",
    "TypeConversionSettings",
    "UntilActivity",
    "UpdateLandingZoneCredential",
    "UserProperty",
    "ValidationActivity",
    "VariableSpecification",
    "VerticaLinkedService",
    "VerticaSource",
    "VerticaTableDataset",
    "VirtualNetworkProfile",
    "WaitActivity",
    "WarehouseLinkedService",
    "WarehouseSink",
    "WarehouseSource",
    "WarehouseTableDataset",
    "WebActivity",
    "WebActivityAuthentication",
    "WebAnonymousAuthentication",
    "WebBasicAuthentication",
    "WebClientCertificateAuthentication",
    "WebHookActivity",
    "WebLinkedService",
    "WebLinkedServiceTypeProperties",
    "WebSource",
    "WebTableDataset",
    "Workspace",
    "WorkspaceIdentity",
    "WorkspaceKeyDetails",
    "WorkspaceRepositoryConfiguration",
    "WorkspaceUpdateParameters",
    "XeroLinkedService",
    "XeroObjectDataset",
    "XeroSource",
    "XmlDataset",
    "XmlReadSettings",
    "XmlSource",
    "ZendeskLinkedService",
    "ZipDeflateReadSettings",
    "ZohoLinkedService",
    "ZohoObjectDataset",
    "ZohoSource",
    "ActionOnExistingTargetTable",
    "ActivityOnInactiveMarkAs",
    "ActivityState",
    "AmazonRdsForOracleAuthenticationType",
    "AmazonRdsForOraclePartitionOption",
    "AmazonRdsForSqlServerAuthenticationType",
    "AvroCompressionCodec",
    "AzureFunctionActivityMethod",
    "AzurePostgreSqlWriteMethodEnum",
    "AzureSearchIndexWriteBehaviorType",
    "AzureSqlDWAuthenticationType",
    "AzureSqlDatabaseAuthenticationType",
    "AzureSqlMIAuthenticationType",
    "AzureStorageAuthenticationType",
    "BigDataPoolReferenceType",
    "BlobEventType",
    "CassandraSourceReadConsistencyLevels",
    "CellOutputType",
    "CompressionCodec",
    "ConfigurationType",
    "CopyBehaviorType",
    "CreateMode",
    "CredentialReferenceType",
    "DataFlowComputeType",
    "DataFlowDebugCommandType",
    "DataFlowReferenceType",
    "DatasetCompressionLevel",
    "DatasetReferenceType",
    "DayOfWeek",
    "Db2AuthenticationType",
    "DependencyCondition",
    "DynamicsAuthenticationType",
    "DynamicsDeploymentType",
    "DynamicsServicePrincipalCredentialType",
    "DynamicsSinkWriteBehavior",
    "Enum13",
    "EventSubscriptionStatus",
    "ExpressionType",
    "ExpressionV2Type",
    "FtpAuthenticationType",
    "GoogleAdWordsAuthenticationType",
    "GoogleBigQueryAuthenticationType",
    "GoogleBigQueryV2AuthenticationType",
    "GreenplumAuthenticationType",
    "HBaseAuthenticationType",
    "HDInsightActivityDebugInfoOption",
    "HDInsightClusterAuthenticationType",
    "HdiNodeTypes",
    "HiveAuthenticationType",
    "HiveServerType",
    "HiveThriftTransportProtocol",
    "HttpAuthenticationType",
    "ImpalaAuthenticationType",
    "ImpalaThriftTransportProtocol",
    "IntegrationRuntimeEdition",
    "IntegrationRuntimeEntityReferenceType",
    "IntegrationRuntimeLicenseType",
    "IntegrationRuntimeReferenceType",
    "IntegrationRuntimeSsisCatalogPricingTier",
    "IntegrationRuntimeState",
    "IntegrationRuntimeType",
    "JsonFormatFilePattern",
    "JsonWriteFilePattern",
    "LakehouseAuthenticationType",
    "LivyStates",
    "ManagedVirtualNetworkReferenceType",
    "MongoDbAuthenticationType",
    "NetezzaPartitionOption",
    "NodeSize",
    "NodeSizeFamily",
    "NotebookParameterType",
    "NotebookReferenceType",
    "ODataAadServicePrincipalCredentialType",
    "ODataAuthenticationType",
    "OracleAuthenticationType",
    "OraclePartitionOption",
    "OrcCompressionCodec",
    "ParameterType",
    "ParquetCompressionCodecEnum",
    "PhoenixAuthenticationType",
    "PipelineReferenceType",
    "PluginCurrentState",
    "PolybaseSettingsRejectType",
    "PrestoAuthenticationType",
    "RecurrenceFrequency",
    "RequestStatus",
    "ResourceIdentityType",
    "ResourceStatus",
    "RestServiceAuthenticationType",
    "RunQueryFilterOperand",
    "RunQueryFilterOperator",
    "RunQueryOrder",
    "RunQueryOrderByField",
    "SalesforceSinkWriteBehavior",
    "SalesforceSourceReadBehavior",
    "SalesforceV2SinkWriteBehavior",
    "SapCloudForCustomerSinkWriteBehavior",
    "SapHanaAuthenticationType",
    "SapHanaPartitionOption",
    "SapTablePartitionOption",
    "SchedulerCurrentState",
    "ScriptActivityLogDestination",
    "ScriptActivityParameterDirection",
    "ScriptActivityParameterType",
    "ScriptType",
    "ServiceNowAuthenticationType",
    "ServiceNowV2AuthenticationType",
    "SftpAuthenticationType",
    "SnowflakeAuthenticationType",
    "SparkAuthenticationType",
    "SparkBatchJobResultType",
    "SparkConfigurationReferenceType",
    "SparkErrorSource",
    "SparkJobReferenceType",
    "SparkJobType",
    "SparkServerType",
    "SparkThriftTransportProtocol",
    "SqlAlwaysEncryptedAkvAuthType",
    "SqlConnectionType",
    "SqlPartitionOption",
    "SqlPoolReferenceType",
    "SqlScriptType",
    "SqlServerAuthenticationType",
    "SsisLogLocationType",
    "SsisPackageLocationType",
    "StoredProcedureParameterType",
    "SybaseAuthenticationType",
    "TeamDeskAuthenticationType",
    "TeradataAuthenticationType",
    "TeradataPartitionOption",
    "TriggerReferenceType",
    "TriggerRunStatus",
    "TriggerRuntimeState",
    "TumblingWindowFrequency",
    "Type",
    "ValueType",
    "VariableType",
    "WarehouseAuthenticationType",
    "WebActivityMethod",
    "WebAuthenticationType",
    "WebHookActivityMethod",
    "ZendeskAuthenticationType",
]
__all__.extend([p for p in _patch_all if p not in __all__])
_patch_sdk()
